==> ui-18.1.0.tgz: package/components/date-picker/DatePicker.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isBoolean, isUndefined } from 'lodash';
import React, { useRef } from 'react';
import { CalendarOutlined } from '@react-devui/icons';
import { getClassName } from '@react-devui/utils';
import { useGeneralContext } from '../../hooks';
import { registerComponentMate } from '../../utils';
import { DDateInput } from '../_date-input';
import { getCols, orderDate } from '../_date-input/utils';
import { DButton } from '../button';
import { useComponentConfig, usePrefixConfig, useTranslation } from '../root';
import { DTag } from '../tag';
import { DPanel as DTimePickerPanel } from '../time-picker/Panel';
import { DPanel } from './Panel';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DDatePicker' });
function DatePicker(props, ref) {
    var _a;
    const _b = useComponentConfig(COMPONENT_NAME, props), { dRef, dFormControl, dModel, dFormat, dVisible, dPlacement = 'bottom-left', dOrder = 'ascend', dPlaceholder, dRange = false, dSize, dClearable = false, dDisabled = false, dPresetDate, dConfigDate, dShowTime = false, dPopupClassName, dInputRender, onModelChange, onVisibleChange, afterVisibleChange, onClear } = _b, restProps = __rest(_b, ["dRef", "dFormControl", "dModel", "dFormat", "dVisible", "dPlacement", "dOrder", "dPlaceholder", "dRange", "dSize", "dClearable", "dDisabled", "dPresetDate", "dConfigDate", "dShowTime", "dPopupClassName", "dInputRender", "onModelChange", "onVisibleChange", "afterVisibleChange", "onClear"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gSize, gDisabled } = useGeneralContext();
    //#endregion
    //#region Ref
    const updatePanelRef = useRef(null);
    const updateTimePickerPanelRef = useRef(null);
    //#endregion
    const [t] = useTranslation();
    const size = dSize !== null && dSize !== void 0 ? dSize : gSize;
    const disabled = (_a = (dDisabled || gDisabled || (dFormControl === null || dFormControl === void 0 ? void 0 : dFormControl.control.disabled))) !== null && _a !== void 0 ? _a : false;
    const format = isUndefined(dFormat)
        ? dShowTime
            ? !isBoolean(dShowTime) && dShowTime.d12Hour
                ? 'YYYY-MM-DD hh:mm:ss A'
                : 'YYYY-MM-DD HH:mm:ss'
            : `YYYY-MM-DD`
        : dFormat;
    const [placeholderLeft = t('DatePicker', dRange ? 'Start date' : 'Select date'), placeholderRight = t('DatePicker', 'End date')] = (dRange ? dPlaceholder !== null && dPlaceholder !== void 0 ? dPlaceholder : [] : [dPlaceholder]);
    const { d12Hour: t12Hour = false, dConfigTime } = isBoolean(dShowTime)
        ? {}
        : dShowTime;
    return (_jsx(DDateInput, Object.assign({}, restProps, { ref: ref, dRef: dRef, dClassNamePrefix: "date-picker", dFormControl: dFormControl, dModel: dModel, dFormat: format, dVisible: dVisible, dPlacement: dPlacement, dOrder: (date) => orderDate(date, dOrder, dShowTime ? undefined : 'date'), dPlaceholder: [placeholderLeft, placeholderRight], dSuffix: _jsx(CalendarOutlined, {}), dRange: dRange, dSize: size, dClearable: dClearable, dDisabled: disabled, dInputRender: dInputRender, onModelChange: onModelChange, onVisibleChange: onVisibleChange, onUpdatePanel: (date) => {
            var _a, _b;
            (_a = updatePanelRef.current) === null || _a === void 0 ? void 0 : _a.call(updatePanelRef, date);
            (_b = updateTimePickerPanelRef.current) === null || _b === void 0 ? void 0 : _b.call(updateTimePickerPanelRef, date);
        }, afterVisibleChange: afterVisibleChange, onClear: onClear }, { children: ({ date, isFocus, changeDate, renderPopup }) => {
            const index = isFocus[0] ? 0 : 1;
            const position = isFocus[0] ? 'start' : 'end';
            return renderPopup(_jsxs("div", Object.assign({ className: getClassName(dPopupClassName, `${dPrefix}date-picker__popup`) }, { children: [_jsx(DPanel, { ref: updatePanelRef, dDateCurrentSelected: date[index], dDateAnotherSelected: date[isFocus[0] ? 1 : 0], dConfigDate: dConfigDate ? (...args) => dConfigDate(...args, position, date) : undefined, onDateChange: changeDate }), dShowTime &&
                        React.cloneElement(_jsx(DTimePickerPanel, { ref: updateTimePickerPanelRef, dTime: date[index], dCols: getCols(format), d12Hour: t12Hour, dConfigTime: dConfigTime ? (...args) => dConfigTime(...args, position, date) : undefined, onTimeChange: changeDate }), {
                            __header: true,
                        }), _jsx("div", Object.assign({ className: getClassName(`${dPrefix}date-picker__footer`, {
                            [`${dPrefix}date-picker__footer--custom`]: dPresetDate,
                        }) }, { children: dPresetDate ? (Object.keys(dPresetDate).map((name) => {
                            const handleClick = () => {
                                var _a, _b;
                                const d = dPresetDate[name]();
                                changeDate(d);
                                (_a = updatePanelRef.current) === null || _a === void 0 ? void 0 : _a.call(updatePanelRef, d[index]);
                                (_b = updateTimePickerPanelRef.current) === null || _b === void 0 ? void 0 : _b.call(updateTimePickerPanelRef, d[index]);
                            };
                            return (_jsx(DTag, Object.assign({ className: `${dPrefix}date-picker__footer-button`, role: "button", onClick: handleClick, dTheme: "primary" }, { children: name }), name));
                        })) : (_jsx(DButton, Object.assign({ onClick: () => {
                                var _a, _b;
                                const now = new Date();
                                changeDate(now);
                                (_a = updatePanelRef.current) === null || _a === void 0 ? void 0 : _a.call(updatePanelRef, now);
                                (_b = updateTimePickerPanelRef.current) === null || _b === void 0 ? void 0 : _b.call(updateTimePickerPanelRef, now);
                            }, dType: "link" }, { children: t('DatePicker', dShowTime ? 'Now' : 'Today') }))) }))] })));
        } })));
}
export const DDatePicker = React.forwardRef(DatePicker);

==> ui-18.3.1.tgz: package/components/date-picker/DatePicker.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isBoolean, isUndefined } from 'lodash';
import React, { useRef } from 'react';
import { CalendarOutlined } from '@react-devui/icons';
import { getClassName } from '@react-devui/utils';
import { useDValue, useGeneralContext } from '../../hooks';
import { registerComponentMate } from '../../utils';
import { DDateInput } from '../_date-input';
import { getCols, orderDate } from '../_date-input/utils';
import { DButton } from '../button';
import { useComponentConfig, usePrefixConfig, useTranslation } from '../root';
import { DTag } from '../tag';
import { DPanel as DTimePickerPanel } from '../time-picker/Panel';
import { DPanel } from './Panel';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DDatePicker' });
function DatePicker(props, ref) {
    var _a;
    const _b = useComponentConfig(COMPONENT_NAME, props), { dRef, dFormControl, dModel, dFormat, dVisible, dPlacement = 'bottom-left', dOrder = 'ascend', dPlaceholder, dRange = false, dSize, dClearable = false, dDisabled = false, dPresetDate, dConfigDate, dShowTime = false, dPopupClassName, dInputRender, onModelChange, onVisibleChange, afterVisibleChange, onClear } = _b, restProps = __rest(_b, ["dRef", "dFormControl", "dModel", "dFormat", "dVisible", "dPlacement", "dOrder", "dPlaceholder", "dRange", "dSize", "dClearable", "dDisabled", "dPresetDate", "dConfigDate", "dShowTime", "dPopupClassName", "dInputRender", "onModelChange", "onVisibleChange", "afterVisibleChange", "onClear"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gSize, gDisabled } = useGeneralContext();
    //#endregion
    //#region Ref
    const updatePanelRef = useRef(null);
    const updateTimePickerPanelRef = useRef(null);
    //#endregion
    const [t] = useTranslation();
    const [visible, changeVisible] = useDValue(false, dVisible, onVisibleChange);
    const size = dSize !== null && dSize !== void 0 ? dSize : gSize;
    const disabled = (_a = (dDisabled || gDisabled || (dFormControl === null || dFormControl === void 0 ? void 0 : dFormControl.control.disabled))) !== null && _a !== void 0 ? _a : false;
    const format = isUndefined(dFormat)
        ? dShowTime
            ? !isBoolean(dShowTime) && dShowTime.d12Hour
                ? 'YYYY-MM-DD hh:mm:ss A'
                : 'YYYY-MM-DD HH:mm:ss'
            : `YYYY-MM-DD`
        : dFormat;
    const [placeholderLeft = t('DatePicker', dRange ? 'Start date' : 'Select date'), placeholderRight = t('DatePicker', 'End date')] = (dRange ? dPlaceholder !== null && dPlaceholder !== void 0 ? dPlaceholder : [] : [dPlaceholder]);
    const { d12Hour: t12Hour = false, dConfigTime } = isBoolean(dShowTime)
        ? {}
        : dShowTime;
    return (_jsx(DDateInput, Object.assign({}, restProps, { ref: ref, dRef: dRef, dClassNamePrefix: "date-picker", dFormControl: dFormControl, dModel: dModel, dFormat: format, dVisible: visible, dPlacement: dPlacement, dOrder: (date) => orderDate(date, dOrder, dShowTime ? undefined : 'date'), dPlaceholder: [placeholderLeft, placeholderRight], dSuffix: _jsx(CalendarOutlined, {}), dRange: dRange, dSize: size, dClearable: dClearable, dDisabled: disabled, dInputRender: dInputRender, onModelChange: onModelChange, onVisibleChange: changeVisible, onUpdatePanel: (date) => {
            var _a, _b;
            (_a = updatePanelRef.current) === null || _a === void 0 ? void 0 : _a.call(updatePanelRef, date);
            (_b = updateTimePickerPanelRef.current) === null || _b === void 0 ? void 0 : _b.call(updateTimePickerPanelRef, date);
        }, afterVisibleChange: afterVisibleChange, onClear: onClear }, { children: ({ date, isFocus, changeDate, renderPopup }) => {
            const index = isFocus[0] ? 0 : 1;
            const position = isFocus[0] ? 'start' : 'end';
            return renderPopup(_jsxs("div", Object.assign({ className: getClassName(dPopupClassName, `${dPrefix}date-picker__popup`) }, { children: [_jsx(DPanel, { ref: updatePanelRef, dDateCurrentSelected: date[index], dDateAnotherSelected: date[isFocus[0] ? 1 : 0], dConfigDate: dConfigDate ? (...args) => dConfigDate(...args, position, date) : undefined, onDateChange: (date) => {
                            changeDate(date);
                            if (!dShowTime) {
                                changeVisible(false);
                            }
                        } }), dShowTime &&
                        React.cloneElement(_jsx(DTimePickerPanel, { ref: updateTimePickerPanelRef, dTime: date[index], dCols: getCols(format), d12Hour: t12Hour, dConfigTime: dConfigTime ? (...args) => dConfigTime(...args, position, date) : undefined, onTimeChange: changeDate }), {
                            __header: true,
                        }), _jsx("div", Object.assign({ className: getClassName(`${dPrefix}date-picker__footer`, {
                            [`${dPrefix}date-picker__footer--custom`]: dPresetDate,
                        }) }, { children: dPresetDate ? (Object.keys(dPresetDate).map((name) => {
                            const handleClick = () => {
                                var _a, _b;
                                const d = dPresetDate[name]();
                                changeDate(d);
                                (_a = updatePanelRef.current) === null || _a === void 0 ? void 0 : _a.call(updatePanelRef, d[index]);
                                (_b = updateTimePickerPanelRef.current) === null || _b === void 0 ? void 0 : _b.call(updateTimePickerPanelRef, d[index]);
                                changeVisible(false);
                            };
                            return (_jsx(DTag, Object.assign({ className: `${dPrefix}date-picker__footer-button`, role: "button", onClick: handleClick, dTheme: "primary" }, { children: name }), name));
                        })) : (_jsx(DButton, Object.assign({ onClick: () => {
                                var _a, _b;
                                const now = new Date();
                                changeDate(now);
                                (_a = updatePanelRef.current) === null || _a === void 0 ? void 0 : _a.call(updatePanelRef, now);
                                (_b = updateTimePickerPanelRef.current) === null || _b === void 0 ? void 0 : _b.call(updateTimePickerPanelRef, now);
                                changeVisible(false);
                            }, dType: "link" }, { children: t('DatePicker', dShowTime ? 'Now' : 'Today') }))) }))] })));
        } })));
}
export const DDatePicker = React.forwardRef(DatePicker);
